# remirepo spec file for php-aws-php-sns-message-validator, from:
#
# Fedora spec file for php-aws-php-sns-message-validator
#
# Copyright (c) 2016-2020 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     aws
%global github_name      aws-php-sns-message-validator
%global github_version   1.6.0
%global github_commit    ba6810807ac8936317021ccc14cdb1297d525ae1

%global composer_vendor  aws
%global composer_project aws-php-sns-message-validator

# "php": ">=5.4"
%global php_min_ver 5.4
# "guzzlehttp/psr7": "^1.4"
%global guzzlehttp_psr7_min_ver 1.4
%global guzzlehttp_psr7_max_ver 2.0
# "psr/http-message": "^1.0"
%global psr_http_message_min_ver 1.0
%global psr_http_message_max_ver 2.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

# Range dependencies supported?
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
%global with_range_dependencies 1
%else
%global with_range_dependencies 0
%endif

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Amazon SNS message validation

License:       ASL 2.0
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-openssl
%if %{with_range_dependencies}
BuildRequires: (php-composer(guzzlehttp/psr7) >= %{guzzlehttp_psr7_min_ver} with php-composer(guzzlehttp/psr7) < %{guzzlehttp_psr7_max_ver})
BuildRequires: (php-composer(psr/http-message) >= %{psr_http_message_min_ver} with php-composer(psr/http-message) < %{psr_http_message_max_ver})
%else
BuildRequires: php-composer(guzzlehttp/psr7) <  %{guzzlehttp_psr7_max_ver}
BuildRequires: php-composer(guzzlehttp/psr7) >= %{guzzlehttp_psr7_min_ver}
BuildRequires: php-composer(psr/http-message) <  %{psr_http_message_max_ver}
BuildRequires: php-composer(psr/http-message) >= %{psr_http_message_min_ver}
%endif
## phpcompatinfo (computed from version 1.6.0)
BuildRequires: php-date
BuildRequires: php-json
BuildRequires: php-pcre
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
%if %{with_range_dependencies}
Requires:      (php-composer(psr/http-message) >= %{psr_http_message_min_ver} with php-composer(psr/http-message) < %{psr_http_message_max_ver})
%else
Requires:      php-composer(psr/http-message) <  %{psr_http_message_max_ver}
Requires:      php-composer(psr/http-message) >= %{psr_http_message_min_ver}
%endif
Requires:      php-openssl
# phpcompatinfo (computed from version 1.6.0)
Requires:      php-json
Requires:      php-pcre
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Standard "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" naming
Provides:      php-%{composer_vendor}-%{composer_project} = %{version}-%{release}
# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
The Amazon SNS Message Validator for PHP library allows you to validate that
incoming HTTP(S) POST messages are valid Amazon SNS notifications. This library
is standalone and does not depend on the AWS SDK for PHP or Guzzle.

Autoloader: %{phpdir}/Aws/Sns/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}

: Fix spurious-executable-perm
: https://github.com/aws/aws-php-sns-message-validator/pull/28
chmod a-x composer.json


%build
: Create autoloader
cat <<'AUTOLOAD' | tee src/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Aws\\Sns\\', __DIR__);

\Fedora\Autoloader\Dependencies::required([
    '%{phpdir}/Psr/Http/Message/autoload.php',
]);
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/Aws
cp -rp src %{buildroot}%{phpdir}/Aws/Sns


%check
%if %{with_tests}
: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Aws/Sns/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Aws\\Sns\\', __DIR__.'/tests');

\Fedora\Autoloader\Dependencies::required([
    '%{phpdir}/GuzzleHttp/Psr7/autoload.php',
]);
BOOTSTRAP

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in "" %{?rhel:php55} php56 php70 php71 php72 php73 php74; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose --bootstrap bootstrap.php \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE.md
%doc composer.json
%doc README.md
%dir %{phpdir}/Aws
     %{phpdir}/Aws/Sns


%changelog
* Sun Apr 05 2020 Shawn Iwinski <shawn@iwin.ski> - 1.6.0-1
- Update to 1.6.0 (RHBZ #1771129)

* Sun Jun 16 2019 Shawn Iwinski <shawn@iwin.ski> - 1.5.0-1
- Update to 1.5.0 (RHBZ #1496609)
- Add range version dependencies for Fedora >= 27 || RHEL >= 8

* Fri Sep 08 2017 Shawn Iwinski <shawn@iwin.ski> - 1.3.0-1
- Update to 1.3.0 (RHBZ #1486494)

* Wed Jul 12 2017 Shawn Iwinski <shawn@iwin.ski> - 1.2.0-1
- Update to 1.2.0 (RHBZ #1470413)
- Test with SCLs if available

* Wed May 10 2017 Valentin Collet <valentin@famillecollet.com> - 1.1.0-3
- Switch to fedora/autoloader

* Sat Apr 16 2016 Remi Collet <remi@remirepo.net> - 1.1.0-1
- backport for remi repository

* Mon Apr 11 2016 Shawn Iwinski <shawn@iwin.ski> - 1.1.0-1
- Initial package
